@@ -46,17 +46,33 @@ class BlockParser:
         if not block["has_children"]:
             return None
 
+        if block["type"] == 'child_page':
+            return None
+
         # 指定类型才递归
         if block["type"] != "to_do" \
                 and block["type"] != "numbered_list_item" \
                 and block["type"] != "bulleted_list_item" \
                 and block["type"] != "toggle" \
                 and block["type"] != "table" \
-                and block["type"] != "table_row":
+                and block["type"] != "table_row"\
+                and block["type"] != "column_list" \
+                and block["type"] != "column" \
+                and block["type"] != "synced_block" \
+                and block["type"] != "heading_1" \
+                and block["type"] != "heading_2" \
+                and block["type"] != "heading_3":
+            common_op.debug_log("[ISSUE] type " + block["type"] + " has no child", level=NotionDump.DUMP_MODE_DEFAULT)
             return None
 
         # 获取块id下面的内容并继续解析
-        block_list = self.query_handle.retrieve_block_children(block["id"])["results"]
+        if block["type"] == "synced_block" and block["synced_block"]["synced_from"] is not None:
+            block_id = block["synced_block"]["synced_from"]["block_id"]
+            common_op.debug_log("type synced_block " + block_id + " get child", level=NotionDump.DUMP_MODE_DEFAULT)
+        else:
+            block_id = block["id"]
+        block_list = self.query_handle.retrieve_block_children(block_id)["results"]
+
         # 如果没有获取到块，也返回空
         if len(block_list) == 0:
             return None
@@ -135,7 +151,7 @@ class BlockParser:
             # Page link_to_page
             block_text = self.base_parser.link_to_page_parser(block, self.parser_type)
         else:
-            common_op.debug_log("unknown page block properties type:" + block_type, level=NotionDump.DUMP_MODE_DEFAULT)
+            common_op.debug_log("[ISSUE] unknown page block properties type:" + block_type, level=NotionDump.DUMP_MODE_DEFAULT)
         return block_text
 
     def parser_block_list(self, block_list, indent=0):
@@ -169,22 +185,44 @@ class BlockParser:
             if block_type != "table" and block_type != "table_row":
                 block_text += prefix
 
-            block_text += self.parser_block(
-                block=block,
-                list_index=list_index,
-                last_line_is_table=last_line_is_table
-            )
+            # 在外面解析列类型
+            if block_type == "column_list":
+                # 列类型的分解
+                column_list = self.__get_children_block_list(block)
+                if column_list is not None:
+                    for column in column_list:
+                        column_rows = self.__get_children_block_list(column)
+                        if column_rows is not None:
+                            block_text += self.parser_block_list(column_rows, indent)
+                        block_text += "\n"
+            elif block_type == "synced_block":
+                # 同步块解析其中的内容
+                synced_block_list = self.__get_children_block_list(block)
+                if synced_block_list is not None:
+                    block_text += self.parser_block_list(synced_block_list, indent)
+                block_text += "\n"
+            else:
+                block_text += self.parser_block(
+                    block=block,
+                    list_index=list_index,
+                    last_line_is_table=last_line_is_table
+                )
+
+                # 看改块下面有没有子块，如果有就继续解析
+                children_block_list = self.__get_children_block_list(block)
+                if children_block_list is not None:
+                    if block_type == "heading_1" or block_type == "heading_2" or block_type == "heading_3":
+                        # 不需要收缩indent值
+                        block_text += "\n"
+                        block_text += self.parser_block_list(children_block_list, indent)
+                    else:
+                        block_text += self.parser_block_list(children_block_list, indent + 1)
+                block_text += "\n"
 
             if block_type == "table_row":
                 # 第一行设置首行标志
                 last_line_is_table = False
 
-            # 看改块下面有没有子块，如果有就继续解析
-            children_block_list = self.__get_children_block_list(block)
-            if children_block_list is not None:
-                block_text += self.parser_block_list(children_block_list, indent + 1)
-            block_text += "\n"
-
         return block_text
 
     def block_to_md(self, block_handle, new_id=None):
@@ -195,6 +233,7 @@ class BlockParser:
 
         # 创建Markdown文件
         if new_id is not None:
+            self.base_parser.set_new_id(new_id)
             tmp_md_filename = self.tmp_dir + new_id.replace('-', '') + ".md"
         else:
             tmp_md_filename = self.tmp_dir + self.block_id + ".md"
