@@ -15,7 +15,7 @@ MD_DIVIDER = "------"
 DUMP_MODE_DEBUG = 0
 DUMP_MODE_DEFAULT = 1
 DUMP_MODE_SILENT = 2
-DUMP_MODE = DUMP_MODE_DEBUG
+DUMP_MODE = DUMP_MODE_DEFAULT
 
 # 导出的类型
 DUMP_TYPE_BLOCK = 1
